==> magento-module-shared-catalog-100.0.7.zip: Plugin/Catalog/Model/DenyPermissionsForNewCategory.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace Magento\SharedCatalog\Plugin\Catalog\Model;

/**
 * Class for setting deny permissions for the new category.
 */
class DenyPermissionsForNewCategory
{
    /**
     * @var \Magento\SharedCatalog\Model\Config\CategoryPermission
     */
    private $configCategoryPermission;

    /**
     * @var \Magento\SharedCatalog\Model\CatalogPermissionManagement
     */
    private $catalogPermissionManagement;

    /**
     * @param \Magento\SharedCatalog\Model\CatalogPermissionManagement $catalogPermissionManagement
     * @param \Magento\SharedCatalog\Model\Config\CategoryPermission $configCategoryPermission
     */
    public function __construct(
        \Magento\SharedCatalog\Model\CatalogPermissionManagement $catalogPermissionManagement,
        \Magento\SharedCatalog\Model\Config\CategoryPermission $configCategoryPermission
    ) {
        $this->catalogPermissionManagement = $catalogPermissionManagement;
        $this->configCategoryPermission = $configCategoryPermission;
    }

    /**
     * Deny permissions for the new category if shared catalog and category permissions features are enabled
     *
     * @param \Magento\Catalog\Model\Category $subject
     * @param \Magento\Catalog\Model\Category $category
     * @return \Magento\Catalog\Model\Category
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterSave(
        \Magento\Catalog\Model\Category $subject,
        \Magento\Catalog\Model\Category $category
    ) {
        if (empty($category->getPermissions()) && $this->configCategoryPermission->isConfigEnable()) {
            $this->catalogPermissionManagement->setDenyPermissionsForCategory($category->getId());
        }
        return $category;
    }
}

==> magento-module-shared-catalog-100.0.8.zip: Plugin/Catalog/Model/DenyPermissionsForNewCategory.php <==
<?php
/**
 * Copyright © Magento, Inc. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace Magento\SharedCatalog\Plugin\Catalog\Model;

/**
 * Class for setting deny permissions for the new category.
 */
class DenyPermissionsForNewCategory
{
    /**
     * @var \Magento\SharedCatalog\Model\Config\CategoryPermission
     */
    private $configCategoryPermission;

    /**
     * @var \Magento\SharedCatalog\Model\CatalogPermissionManagement
     */
    private $catalogPermissionManagement;

    /**
     * @param \Magento\SharedCatalog\Model\CatalogPermissionManagement $catalogPermissionManagement
     * @param \Magento\SharedCatalog\Model\Config\CategoryPermission $configCategoryPermission
     */
    public function __construct(
        \Magento\SharedCatalog\Model\CatalogPermissionManagement $catalogPermissionManagement,
        \Magento\SharedCatalog\Model\Config\CategoryPermission $configCategoryPermission
    ) {
        $this->catalogPermissionManagement = $catalogPermissionManagement;
        $this->configCategoryPermission = $configCategoryPermission;
    }

    /**
     * Deny permissions for the new category if shared catalog and category permissions features are enabled
     *
     * @param \Magento\Catalog\Model\Category $subject
     * @param \Magento\Catalog\Model\Category $category
     * @return \Magento\Catalog\Model\Category
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function afterSave(
        \Magento\Catalog\Model\Category $subject,
        \Magento\Catalog\Model\Category $category
    ) {
        if ($category->isObjectNew()
            && empty($category->getPermissions())
            && $this->configCategoryPermission->isConfigEnable()
        ) {
            $this->catalogPermissionManagement->setDenyPermissionsForCategory($category->getId());
        }
        return $category;
    }
}
